@@ -2,49 +2,49 @@
 #'
 #' Create a musical phrase from character strings that define string numbers,
 #' fret numbers and note metadata. This function is a wrapper around
-#' \code{\link{phrase}}.
-#' It allows for specifying string/fret combinations instead of unambiguous
-#' pitch as is used by \code{phrase}.
-#' In order to remove ambiguity, it is critical to specify the instrument
-#' string tuning and key signature.
-#' It essentially uses \code{string} and \code{fret} in combination with a
-#' known tuning and key signature to generate \code{notes} for
-#' \code{\link{phrase}}.
-#' \code{info} is passed straight through to \code{phrase}, as is \code{string}
-#' once it is done being used to help derive \code{notes}.
+#' [phrase()].
+#'
+#' Note: This alternate specification wrapper is not receiving further support
+#' and will be removed in a future version of `tabr`.
+#'
+#' This alternate syntax allows for specifying string/fret combinations instead
+#' of unambiguous pitch as is used by `phrase()`. In order to remove ambiguity,
+#' it is critical to specify the instrument string tuning and key signature. It
+#' essentially uses `string` and `fret` in combination with a known tuning and
+#' key signature to generate `notes` for [phrase()]. `info` is passed straight
+#' through to `phrase()`, as is `string` once it is done being used to help
+#' derive `notes`.
 #'
 #' @details
-#' See the main function \code{phrase} for general details on phrase
+#' See the main function `phrase` for general details on phrase
 #' construction.
 #'
-#' @section Comparison with \code{phrase}:
+#' @section Comparison with `phrase()`:
 #' This function is a wrapper function for users not working with musical notes
 #' (what to play), but rather just position on the guitar neck (where to play).
 #' This approach has conveniences, but is more limiting.
 #' In order to remove ambiguity, it is necessary to specify the instrument
-#' \code{tuning} and the \code{key} signature.
+#' `tuning` and the `key` signature.
 #'
-#' In the standard approach with \code{phrase} you specify what to play;
+#' In the standard approach with `phrase()` you specify what to play;
 #' specifying exactly where to play is optional, but highly recommended (by
-#' providing \code{string}).
-#' With \code{sf_phrase}, the \code{string} argument is of course required
-#' along with \code{fret}.
+#' providing `string`).
+#' With `sf_phrase()`, the `string` argument is of course required along with
+#' `fret`.
 #' But any time the tuning changes, this "where to play" method breaks down and
 #' must be redone. It is more robust to provide the string and pitch rather
 #' than the string and fret.
-#' The \code{key} is additionally important because it is the only way to
+#' The `key` is additionally important because it is the only way to
 #' indicate if accidentals should be notated as sharps or flats.
 #'
 #' This wrapper also increases redundancy and typing. In order to specify rests
-#' \code{r}, silent rests \code{s}, and tied notes \code{~}, these must now be
-#' providing in parallel in both the \code{string} and \code{fret} arguments,
-#' whereas in the standard method using \code{phrase}, they need only be
-#' provided once to \code{notes}.
+#' `r`, silent rests `s`, and tied notes `~`, these must now be providing in
+#' parallel in both the `string` and `fret` arguments, whereas in the standard
+#' method using `phrase()`, they need only be provided once to `notes`.
 #' A mismatch will throw an error. Despite the redundancy, this is helpful for
-#' ensuring proper match up between \code{string} and \code{fret},
-#' which is essentially a dual entry method that aims to reduce itself inside
-#' \code{sf_phrase} to a single \code{notes} string that is passed internally
-#' to \code{phrase}.
+#' ensuring proper match up between `string` and `fret`, which is essentially a
+#' dual entry method that aims to reduce itself inside `sf_phrase()` to a single
+#' `notes` string that is passed internally to `phrase()`.
 #'
 #' The important thing to keep in mind is that by its nature, this method of
 #' writing out music does not lend itself well to high detail.
@@ -52,89 +52,86 @@
 #' important information, and those that attempt to compensate with additional
 #' symbols in say, an ascii tab, are difficult to read.
 #' This wrapper function providing this alternative input method to
-#' \code{phrase} does its job of allowing users to create phrase objects that
-#' are equivalent to standard \code{phrase}-generated objects, including rests
+#' `phrase()` does its job of allowing users to create phrase objects that
+#' are equivalent to standard `phrase()`-generated objects, including rests
 #' and ties.
-#' But practice and comfort working with \code{phrase} is is highly recommended
+#' But practice and comfort working with `phrase()` is is highly recommended
 #' for greater control of development support.
 #'
-#' The function \code{sfp} is a convenient shorthand wrapper for
-#' \code{sf_phrase}. \code{sf_note} and the alias \code{sfn} are wrappers
-#' around \code{sf_phrase} that force \code{to_notes = TRUE}.
+#' The function `sfp()` is a convenient shorthand wrapper for `sf_phrase()`.
+#' `sf_note()` and the alias `sfn()` are wrappers around `sf_phrase()` that
+#' force `to_notes = TRUE`.
 #'
 #' @section Single-string input:
-#' Another way to use \code{sf_phrase} is to provide all musical input to
-#' \code{string} and ignore \code{fret} and \code{info} as explicit arguments.
+#' Another way to use `sf_phrase()` is to provide all musical input to
+#' `string` and ignore `fret` and `info` as explicit arguments.
 #' Providing all three explicit arguments more closely mimics the inputs of
-#' \code{phrase} and is useful when you have this information as three
+#' `phrase()` and is useful when you have this information as three
 #' independent sources.
 #' However, in some cases the single-argument input method can reduce typing,
 #' though this depends on the phrase.
 #' More importantly, it allow you to reason about your musical inputs by time
 #' step rather than by argument.
 #' If you provide all three components as a single character string to the
-#' \code{string} argument, leaving both \code{fret} and \code{info} as
-#' \code{NULL}, then \code{sf_phrase} will decompose \code{string} into its
-#' three component parts internally.
+#' `string` argument, leaving both `fret` and `info` as `NULL`, then
+#' `sf_phrase()` will decompose `string` into its three component parts
+#' internally.
 #'
 #' There are some rules for single-argument input. The three components are
-#' separated by semicolons as \code{"string;fret;info"}.
-#' For example, \code{"3;7x7;4"} means begin on the third string
+#' separated by semicolons as `"string;fret;info"`.
+#' For example, `"3;7x7;4"` means begin on the third string
 #' (infer higher number strings muted).
-#' The frets are 7th and 7th, meaning two notes are played. When an \code{x} is
+#' The frets are 7th and 7th, meaning two notes are played. When an `x` is
 #' present in the second entry it means a string is not played.
 #' This is how it is inferred that the string numbers starting from the third
 #' string are strings 3 and 1 rather than 3 and 2 in this example.
 #' The 4 indicates a quarter note since it is part of the third entry where the
-#' additional \code{info} is specified. This is contextual. For example, an
-#' \code{x} here would still indicate a dead note, rather than an unplayed
+#' additional `info` is specified. This is contextual. For example, an
+#' `x` here would still indicate a dead note, rather than an unplayed
 #' string in the second entry, so this is contextual.
 #'
-#' A bonus when using this input method is that explicit \code{string} and
-#' \code{info} values persist from one timestep to the next.
+#' A bonus when using this input method is that explicit `string` and
+#' `info` values persist from one timestep to the next.
 #' Neither needs to be provided again until there is a change in value.
-#' For example, \code{"3;7x7;4 7x7 ;7x7;1"} repeats the string and info values
+#' For example, `"3;7x7;4 7x7 ;7x7;1"` repeats the string and info values
 #' from timestep one for timestep two.
 #' In timestep three, string numbers repeat again, but the duration changes
 #' from quarter note to whole note.
 #'
-#' Note that except when both \code{string} and \code{info} are repeating and
+#' Note that except when both `string` and `info` are repeating and
 #' only fret numbers are provided (see timestep two above), two semicolons
 #' must be present so that it is unambiguous whether the sole missing component
-#' is a \code{string} or \code{info} (see timestep three).
+#' is a `string` or `info` (see timestep three).
 #'
-#' Ambiguity would arise from a case like \code{"4;4"} without the second
-#' semicolon. This type of indexing was chosen over using two different
-#' delimiters.
+#' Ambiguity would arise from a case like `"4;4"` without the second semicolon.
+#' This type of indexing was chosen over using two different delimiters.
 #'
-#' If a rest, \code{r} or \code{s}, is provided for the \code{fret} entry,
-#' then the \code{string} entry is ignored.
-#' When using this input method, ties \code{~} are given in the info entry.
+#' If a rest, `r` or `s`, is provided for the `fret` entry, then the `string`
+#' entry is ignored. When using this input method, ties `~` are given in the
+#' info entry.
 #'
 #' See the examples for a comparison of two identical phrases specified using
-#' both input methods for \code{sf_phrase}.
+#' both input methods for `sf_phrase()`.
 #'
 #' @param string character, space-delimited or vector. String numbers
 #' associated with notes. Alternatively, provide all information here in a
-#' single space-delimited string and ignore \code{fret} and \code{info}. See
-#' details.
+#' single space-delimited string and ignore `fret` and `info`. See details.
 #' @param fret character, space-delimited or vector (or integer vector) of fret
-#' numbers associated with notes. Same number of timesteps as \code{string}.
+#' numbers associated with notes. Same number of timesteps as `string`.
 #' @param info character, space-delimited or vector (or integer vector if simple
 #' durations) giving metadata associated with notes. Same number of timesteps as
-#' \code{string}.
-#' @param key character, key signature or just specify \code{"sharp"} or
-#' \code{"flat"}.
+#' `string`.
+#' @param key character, key signature or just specify `"sharp"` or `"flat"`.
 #' @param tuning character, instrument tuning.
 #' @param to_notes logical, return only the mapped notes character string
 #' rather than the entire phrase object.
-#' @param bar character or \code{NULL} (default). Terminates the phrase with a
-#' bar or bar check. See details for \code{\link{phrase}}. Also see the
-#' LilyPond help documentation on bar notation for all the valid options.
-#' @param ... arguments passed to \code{sf_phrase}.
+#' @param bar character or `NULL` (default). Terminates the phrase with a
+#' bar or bar check. See details for [phrase()]. Also see the LilyPond help
+#' documentation on bar notation for all the valid options.
+#' @param ... arguments passed to `sf_phrase()`.
 #'
 #' @return a phrase.
-#' @seealso \code{\link{phrase}}
+#' @seealso [phrase()]
 #' @export
 #'
 #' @examples
@@ -203,8 +200,8 @@ sf_phrase <- function(string, fret = NULL, info = NULL, key = "c",
       } else {
         strsplit(x, "")[[1]]
       }
-      }) %>%
-      unlist() %>%
+      }) |>
+      unlist() |>
       as.integer()
     if(length(x) != length(y)) stop("String/fret mismatch.", call. = FALSE)
     x <- sapply(seq_along(x), function(i, x, y){
@@ -212,8 +209,8 @@ sf_phrase <- function(string, fret = NULL, info = NULL, key = "c",
     }, x = x, y = y)
     if(any(string_tie)) x[string_tie] <- paste0(x[string_tie], "~")
     paste(x, collapse = "")
-  })) %>%
-    unlist() %>%
+  })) |>
+    unlist() |>
     paste(collapse = " ")
   if(to_notes) return(as_noteworthy(notes))
   phrase(notes, info, gsub("~", "", string), bar)
@@ -274,14 +271,14 @@ sfn <- sf_note
   if(is.na(x[[1]][1]) | is.na(x[[1]][3]))
     stop("First timestep must include all three values as `string;fret;info`.",
          call. = FALSE)
-  x <- do.call(rbind, x) %>%
-    as.data.frame(stringsAsFactors = FALSE) %>%
-    stats::setNames(c("string", "fret", "info")) %>%
-    tibble::as_tibble() %>%
-    tidyr::fill(.data[["string"]], .data[["info"]]) %>%
+  x <- do.call(rbind, x) |>
+    as.data.frame(stringsAsFactors = FALSE) |>
+    stats::setNames(c("string", "fret", "info")) |>
+    tibble::as_tibble() |>
+    tidyr::fill("string", "info") |>
     dplyr::mutate(
       string = .infer_strings(.data[["string"]], .data[["fret"]]),
-      fret = gsub("x", "", .data[["fret"]])) %>%
+      fret = gsub("x", "", .data[["fret"]])) |>
     dplyr::slice(rep(seq_len(length(x)), times = mult))
   idx <- grep("~", x$info)
   if(length(idx)){
